/* eslint-disable react/prop-types */
import { h, Fragment } from 'preact'
import { isFuture, isPast } from 'date-fns'

import { P } from '../Text'
import translations from '../../data/strings'
import InfoLayout from '../InfoLayout'
import {
  VideoCard,
  Title,
  InfoContent,
  PositionedCross as CrossSvg,
} from './styles'

const Info = ({ data, loading, infoActive, setInfoActive, currentVideo }) => {
  const pastStreams =
    data && data.length
      ? data.filter(feeditem => isPast(new Date(feeditem.end)))
      : []

  const futureStreams =
    data && data.length
      ? data.filter(
          feeditem =>
            feeditem.id !== (currentVideo && currentVideo.id) &&
            isFuture(new Date(feeditem.start))
        )
      : []

  console.log({ currentVideo })

  return (
    <InfoLayout loading={loading}>
      {infoActive && <CrossSvg onClick={() => setInfoActive(false)} />}
      {!loading && (
        <InfoContent>
          {currentVideo && (
            <Fragment>
              <Title>{translations.en.nowPlaying}:</Title>
              <VideoCard {...currentVideo} />
            </Fragment>
          )}

          {futureStreams.length && (
            <Fragment>
              <Title>{translations.en.nextStream}:</Title>
              {futureStreams.map(feeditem => (
                <VideoCard key={feeditem.start} {...feeditem} />
              ))}
            </Fragment>
          )}

          {pastStreams.length ? (
            <Fragment>
              <Title>{translations.en.pastStream}:</Title>
              {pastStreams.map(feeditem => (
                <VideoCard key={feeditem.start} hasPassed {...feeditem} />
              ))}
            </Fragment>
          ) : null}
        </InfoContent>
      )}
    </InfoLayout>
  )
}

export default Info
