import { format } from 'date-fns'
import { h, Fragment } from 'preact'
import styled from 'styled-components'
import { colours } from '../../assets/theme'
import config from '../../data/config'
import Logo from '../Logo'
import translations from '../../data/strings'
import CrossSvg from '../Svg/Cross'

import { P, H1, H2, Span, Label } from '../Text'
import Link from '../Link'
import { bool, instanceOf, string } from 'prop-types'

export const Wrapper = styled.div`
  height: 100vh;
  width: 100vw;
  padding: 2em;
  display: flex;
  justify-content: space-between;
  flex-direction: column;

  background: url(https://images.unsplash.com/photo-1579762715118-a6f1d4b934f1?ixlib=rb-1.2.1&ixid=MXwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHw%3D&auto=format&fit=crop&w=3031&q=80)
    ${colours.rose};
  box-sizing: border-box;
  background-size: cover;
  background-position-y: 50%;
  background-position-x: 20vw;
  background-blend-mode: soft-light;

  p,
  h1,
  h2 {
    color: ${colours.midnightDarker};
  }
`

export const Top = styled.div``

export const InfoContent = styled.div`
  padding-bottom: 1em;
`

export const PositionedLogo = styled(Logo)`
  margin-bottom: 64px;
`

export const TaglineContainer = styled.div`
  h1 {
    margin-top: 32px;
  }
`

export const Title = styled(H1)`
  margin: 0.3em 0;
`

export const PositionedCross = styled(CrossSvg)`
  position: fixed;
  right: 2.5em;
  top: 2em;
  width: 24px;
  height: 24px;
  cursor: pointer;
  stroke: ${colours.midnightDarker};

  &:hover {
    opacity: 0.5;
  }
`

const VCWrapper = styled.div`
  max-width: 600px;
  margin: 0 0 6em 2px;
  border-left: 5px solid ${colours.midnightDarker};
  padding-left: 1em;
`

const VCImg = styled.img`
  width: 100%;
`

const ItemTitle = styled(H2)`
  margin-bottom: 0.3em;
`

const DateLabel = styled(Label)`
  margin: 1em 0;
  display: block;
`

const LinkBlock = styled(Link)`
  display: block;
  width: 100%;
`

export const VideoCard = ({
  title,
  description,
  start,
  end,
  previewPath,
  hasPassed,
  videoUrl,
}) => (
  <VCWrapper>
    {videoUrl && hasPassed ? (
      <LinkBlock href={videoUrl}>
        <ItemTitle>{title}</ItemTitle>
        <VCImg src={`${config.peertube_root}${previewPath}`} alt="" />
      </LinkBlock>
    ) : (
      <Fragment>
        <ItemTitle>{title}</ItemTitle>
        <VCImg src={`${config.peertube_root}${previewPath}`} alt="" />
      </Fragment>
    )}
    <DateLabel colour={colours.midnight} size="18">
      {`${
        hasPassed
          ? translations.en.streamDatePast
          : translations.en.streamDateFuture
      }`}
      <Span bold colour={colours.midnight}>
        {format(new Date(start), 'hh:mm dd/MM/yy')}
      </Span>
    </DateLabel>
    <P>{description}</P>
  </VCWrapper>
)

VideoCard.propTypes = {
  title: string,
  description: string,
  start: instanceOf(Date),
  end: instanceOf(Date),
  previewPath: string,
  hasPassed: bool,
  videoUrl: string,
}
